@@ -7,7 +7,7 @@ import logging
 from mkdocs.plugins import BasePlugin
 from mkdocs.utils import warning_filter
 
-from jinja2 import Template
+import jinja2
 from pathlib import Path
 from itertools import chain
 
@@ -27,8 +27,11 @@ class MarkdownExtraDataPlugin(BasePlugin):
     Inject certain config variables into the markdown
     """
 
+    JINJA_OPTIONS = "jinja_options"
+
     config_scheme = (
         ("data", mkdocs.config.config_options.Type(str_type, default=None)),
+        (JINJA_OPTIONS, mkdocs.config.config_options.Type(dict, default={}))
     )
 
     def __add_data__(self, config, namespace, data):
@@ -42,7 +45,7 @@ class MarkdownExtraDataPlugin(BasePlugin):
             del namespace[0]
         holder[namespace[0]] = data
 
-    def on_pre_build(self, config):
+    def on_pre_build(self, config, **kwargs):
         # Loads all data from the supplied data directories
         # or, otherwise a _data directory next to mkdocs.yml and/or inside the docs_dir.
         # Does nothing if the dir does not exist.
@@ -91,5 +94,7 @@ class MarkdownExtraDataPlugin(BasePlugin):
     def on_page_markdown(self, markdown, config, **kwargs):
         context = {key: config.get(key) for key in CONFIG_KEYS if key in config}
         context.update(config.get("extra", {}))
-        md_template = Template(markdown)
+        jinja_options = self.config[self.JINJA_OPTIONS]
+        env = jinja2.Environment(undefined=jinja2.DebugUndefined, **jinja_options)
+        md_template = env.from_string(markdown)
         return md_template.render(**config.get("extra"))
